[svn-commits] mattf: branch mattf/bug13495 r229 - /team/mattf/bug13495/

SVN commits to the Digium repositories svn-commits at lists.digium.com
Fri Dec 5 15:55:24 CST 2008


Author: mattf
Date: Fri Dec  5 15:55:23 2008
New Revision: 229

URL: http://svn.digium.com/view/libss7?view=rev&rev=229
Log:
Fix spelling error in the word adjacent

Modified:
    team/mattf/bug13495/mtp2.h
    team/mattf/bug13495/mtp3.c
    team/mattf/bug13495/mtp3.h
    team/mattf/bug13495/ss7.c
    team/mattf/bug13495/ss7_internal.h

Modified: team/mattf/bug13495/mtp2.h
URL: http://svn.digium.com/view/libss7/team/mattf/bug13495/mtp2.h?view=diff&rev=229&r1=228&r2=229
==============================================================================
--- team/mattf/bug13495/mtp2.h (original)
+++ team/mattf/bug13495/mtp2.h Fri Dec  5 15:55:23 2008
@@ -154,7 +154,7 @@
 	struct ss7_msg *retransmit_pos;
 	struct ss7_msg *co_tx_buf; /* store here before reset_mtp flush it */
 	struct ss7_msg *co_tx_q;
-	struct adjecent_sp *adj_sp;
+	struct adjacent_sp *adj_sp;
 	unsigned char cb_seq;
 	struct ss7 *master;
 };

Modified: team/mattf/bug13495/mtp3.c
URL: http://svn.digium.com/view/libss7/team/mattf/bug13495/mtp3.c?view=diff&rev=229&r1=228&r2=229
==============================================================================
--- team/mattf/bug13495/mtp3.h (original)
+++ team/mattf/bug13495/mtp3.h Fri Dec  5 15:55:23 2008
@@ -167,11 +167,11 @@
 	int t6;
 	int t10;
 	struct ss7_msg *q;
-	struct adjecent_sp *owner;
+	struct adjacent_sp *owner;
 	struct mtp3_route *next;
 };
 
-struct adjecent_sp {
+struct adjacent_sp {
 	int state;
 	unsigned int adjpc;
 	struct mtp2 *links[SS7_MAX_LINKS];
@@ -213,6 +213,6 @@
 
 void mtp3_free_co(struct mtp2 *link);
 
-void mtp3_destroy_all_routes(struct adjecent_sp *adj_sp);
+void mtp3_destroy_all_routes(struct adjacent_sp *adj_sp);
 
 #endif /* _MTP3_H */

Modified: team/mattf/bug13495/ss7.c
URL: http://svn.digium.com/view/libss7/team/mattf/bug13495/ss7.c?view=diff&rev=229&r1=228&r2=229
==============================================================================
--- team/mattf/bug13495/ss7.c (original)
+++ team/mattf/bug13495/ss7.c Fri Dec  5 15:55:23 2008
@@ -551,7 +551,7 @@
 	int j, i, x;
 	char *p;
 	char got_sent_buf[256], timers[512];
-	struct adjecent_sp *adj_sp;
+	struct adjacent_sp *adj_sp;
 	struct mtp2 *link;
 	struct mtp3_route *cur;
 	
@@ -564,7 +564,7 @@
 
 	for (j = 0; j < ss7->numsps; j++) {
 		adj_sp = ss7->adj_sps[j];
-		cust_printf(fd, "  ---------------------------------\n  Adjecent SP PC: %i STATE: %s\n", adj_sp->adjpc, mtp3_state(adj_sp->state));
+		cust_printf(fd, "  ---------------------------------\n  Adjacent SP PC: %i STATE: %s\n", adj_sp->adjpc, mtp3_state(adj_sp->state));
 		cust_printf(fd, "  TRA:  %s%s    T19: %s\n", (adj_sp->tra & GOT) ? "GOT " : "", (adj_sp->tra & SENT) ? "SENT" : "",
 				(adj_sp->timer_t19 > -1) ? "running" : "not running");
 

Modified: team/mattf/bug13495/ss7_internal.h
URL: http://svn.digium.com/view/libss7/team/mattf/bug13495/ss7_internal.h?view=diff&rev=229&r1=228&r2=229
==============================================================================
--- team/mattf/bug13495/ss7_internal.h (original)
+++ team/mattf/bug13495/ss7_internal.h Fri Dec  5 15:55:23 2008
@@ -112,7 +112,7 @@
 
 	unsigned int mtp2_linkstate[SS7_MAX_LINKS];
 	struct mtp2 *links[SS7_MAX_LINKS];
-	struct adjecent_sp *adj_sps[SS7_MAX_ADJSPS];
+	struct adjacent_sp *adj_sps[SS7_MAX_ADJSPS];
 	int isup_timers[ISUP_MAX_TIMERS];
 	int mtp3_timers[MTP3_MAX_TIMERS];
 	unsigned char sls_shift;




More information about the svn-commits mailing list
--- team/mattf/bug13495/mtp3.c (original)
+++ team/mattf/bug13495/mtp3.c Fri Dec  5 15:55:23 2008
@@ -649,7 +649,7 @@
 	ss7_message(link->master, "Changeover cancelled on link SLC %i PC %i\n", link->slc, link->dpc);
 }
 
-static void mtp3_check(struct adjecent_sp *adj_sp)
+static void mtp3_check(struct adjacent_sp *adj_sp)
 {
 	if (!adj_sp)
 		return;
@@ -675,14 +675,14 @@
 			adj_sp->links[i]->inhibit &= ~INHIBITED_REMOTELY;
 		}
 		mtp3_destroy_all_routes(adj_sp);
-		ss7_error(ss7, "Adjecent SP PC: %i DOWN!!!\n", adj_sp->adjpc);
+		ss7_error(ss7, "Adjacent SP PC: %i DOWN!!!\n", adj_sp->adjpc);
 		ss7_check(ss7);
 		return;
 	}
 
 	if (count && adj_sp->state != MTP3_UP && adj_sp->tra & GOT && adj_sp->tra & SENT) {
 		adj_sp->state = MTP3_UP;
-		ss7_message(ss7, "Adjecent SP PC: %i UP!!!\n", adj_sp->adjpc);
+		ss7_message(ss7, "Adjacent SP PC: %i UP!!!\n", adj_sp->adjpc);
 		ss7_check(ss7);
 	}
 }
@@ -690,7 +690,7 @@
 static int mtp3_init(struct mtp2 *link)
 {
 	int res;
-	struct adjecent_sp *adj_sp = link->adj_sp;
+	struct adjacent_sp *adj_sp = link->adj_sp;
 
 	if (adj_sp->state == MTP3_DOWN) {
 		AUTORL(rl, link);
@@ -708,7 +708,7 @@
 
 static void mtp3_restart(struct mtp2 *link)
 {
-	struct adjecent_sp *adj_sp = link->adj_sp;
+	struct adjacent_sp *adj_sp = link->adj_sp;
 	int i;
 	
 	adj_sp->state = MTP3_DOWN;
@@ -739,7 +739,7 @@
 	}
 	
 	
-	struct adjecent_sp *adj_sp = link->adj_sp;
+	struct adjacent_sp *adj_sp = link->adj_sp;
 	
 	if (adj_sp->timer_t19 > -1)
 		ss7_schedule_del(ss7, &adj_sp->timer_t19);
@@ -859,7 +859,7 @@
 
 static void mtp3_t19_expiry(void * data)
 {
-	struct adjecent_sp *adj_sp = data;
+	struct adjacent_sp *adj_sp = data;
 	adj_sp->timer_t19 = -1;
 	ss7_message(adj_sp->master, "MTP3 T19 timer expired PC:%i\n", adj_sp->adjpc);
 }
@@ -902,7 +902,7 @@
 static void mtp3_t10_expired(void *data)
 {
 	struct mtp3_route *route = data;
-	struct adjecent_sp *adj_sp = route->owner;
+	struct adjacent_sp *adj_sp = route->owner;
 	struct ss7 *ss7 = adj_sp->master;
 	struct routing_label rl;
 	
@@ -914,7 +914,7 @@
 	route->t10 = ss7_schedule_event(ss7, ss7->mtp3_timers[MTP3_TIMER_T10], &mtp3_t10_expired, route);
 }
 
-static void mtp3_forced_reroute(struct adjecent_sp *adj_sp, struct mtp3_route *route)
+static void mtp3_forced_reroute(struct adjacent_sp *adj_sp, struct mtp3_route *route)
 {
 	int i = 0;
 	struct ss7 *ss7 = adj_sp->master;
@@ -942,7 +942,7 @@
 	mtp3_transmit_buffer(ss7, &route->q);
 }
 
-static void mtp3_destroy_route(struct adjecent_sp *adj_sp, struct mtp3_route *route)
+static void mtp3_destroy_route(struct adjacent_sp *adj_sp, struct mtp3_route *route)
 {
 	struct mtp3_route *prev;
 	
@@ -971,7 +971,7 @@
 static void mtp3_t6_expired(void *data)
 {
 	struct mtp3_route *route = data;
-	struct adjecent_sp *adj_sp = route->owner;
+	struct adjacent_sp *adj_sp = route->owner;
 	route->t6 = -1;
 	
 	mtp3_transmit_buffer(adj_sp->master, &route->q);
@@ -980,7 +980,7 @@
 		mtp3_destroy_route(adj_sp, route);
 }
 
-static void mtp3_controlled_reroute(struct adjecent_sp *adj_sp, struct mtp3_route *route)
+static void mtp3_controlled_reroute(struct adjacent_sp *adj_sp, struct mtp3_route *route)
 {
 	int i = 0;
 	struct ss7 *ss7 = adj_sp->master;
@@ -1004,7 +1004,7 @@
 	route->t6 = ss7_schedule_event(ss7, ss7->mtp3_timers[MTP3_TIMER_T6], &mtp3_t6_expired, route);
 }
 
-static void mtp3_add_set_route(struct adjecent_sp *adj_sp, unsigned short dpc, int state)
+static void mtp3_add_set_route(struct adjacent_sp *adj_sp, unsigned short dpc, int state)
 {
 	struct mtp3_route *cur = adj_sp->routes;
 	struct mtp3_route *prev = adj_sp->routes;
@@ -1491,7 +1491,7 @@
 	if (can_reroute == 2) { /* COA, ECA try send back on the same link, if available */
 		if (link->std_test_passed) {
 			if ((h0h1 == (NET_MNG_COA) || (h0h1 == (NET_MNG_ECA))) && link->slc == rl.sls)
-				ss7_error(ss7, "The adjecent SP %i sent COO, ECO on the same link: %i, we answer on another!!\n", rl.dpc, rl.sls);
+				ss7_error(ss7, "The adjacent SP %i sent COO, ECO on the same link: %i, we answer on another!!\n", rl.dpc, rl.sls);
 			else {
 				rl.sls = link->slc;
 				return mtp3_transmit(ss7, SIG_NET_MNG, rl, m);
@@ -1520,7 +1520,7 @@
 			rl.sls = link->slc;
 			return mtp3_transmit(ss7, SIG_NET_MNG, rl, m);
 		} else {
 			/* we may use another link to the same adjecent sp */
 			for (i = 0; i < link->adj_sp->numlinks; i++) {
 				if (link->adj_sp->links[i]->std_test_passed) {
 					rl.sls = link->adj_sp->links[i]->slc;
@@ -2019,7 +2019,7 @@
 	return "Unknown";
 }
 
-static inline void mtp3_add_link_adjsps(struct adjecent_sp *adj_sp, struct mtp2 *link)
+static inline void mtp3_add_link_adjsps(struct adjacent_sp *adj_sp, struct mtp2 *link)
 {
 	int i;
 	
@@ -2036,10 +2036,10 @@
 
 static inline void mtp3_new_adjsp(struct ss7 *ss7, struct mtp2 *link)
 {
-	struct adjecent_sp *new;
+	struct adjacent_sp *new;
 
 	if (ss7->numsps == SS7_MAX_ADJSPS) {
-		ss7_error(ss7, "Couldn't add new adjecent sp, reached the %i limit", SS7_MAX_ADJSPS);
+		ss7_error(ss7, "Couldn't add new adjacent sp, reached the %i limit", SS7_MAX_ADJSPS);
 		return;
 	}
 	
@@ -2047,7 +2047,7 @@
 	new = calloc(1, sizeof(struct mtp2));
 
 	if (!new) {
-		ss7_error(ss7, "Couldn't allocate new adjecent SP\n");
+		ss7_error(ss7, "Couldn't allocate new adjacent SP\n");
 		return;
 	}
 	
@@ -2078,7 +2078,7 @@
 		mtp3_new_adjsp(ss7, link);
 }
 
-void mtp3_destroy_all_routes(struct adjecent_sp *adj_sp)
+void mtp3_destroy_all_routes(struct adjacent_sp *adj_sp)
 {
 	struct mtp3_route *next;
 	
@@ -1520,7 +1520,7 @@
 			return mtp3_transmit(ss7, SIG_NET_MNG, rl, m);
 		} else {
-			/* we may use another link to the same adjecent sp */
+			/* we may use another link to the same adjacent sp */
 			for (i = 0; i < link->adj_sp->numlinks; i++) {
 				if (link->adj_sp->links[i]->std_test_passed) {

Modified: team/mattf/bug13495/mtp3.h
URL: http://svn.digium.com/view/libss7/team/mattf/bug13495/mtp3.h?view=diff&rev=229&r1=228&r2=229
==============================================================================